@@ -139,7 +139,7 @@ def get_clustered_mfpt_bins(variance, discrepancy, steady_state, n_desired_we_bi
         indices = np.argwhere(we_bin_assignments == i).squeeze()
         states_in_bin = pi_v_sort[indices]
         bin_states[states_in_bin] = i
-        log.info(f"Found that bin {i} contains microstates {states_in_bin}")
+        log.debug(f"Found that bin {i} contains microstates {states_in_bin}")
 
     return bin_states
 
@@ -224,7 +224,9 @@ class OptimizedBinMapper(westpa.core.binning.FuncBinMapper):
         else:
             final_coords = coords
 
-        log.debug(f"Mapping pcoords {final_coords}")
+        log.info(f"Mapping original coords of shape {coords.shape}")
+        log.info(f"Mapping pcoords {final_coords}")
+        log.info(f"Mapping pcoords of shape {final_coords.shape}")
 
         # To use stratified clustering, first load the ORIGINAL pcoords into stratified.pcoord1List, then call
         #   stratified.predict().
@@ -233,6 +235,7 @@ class OptimizedBinMapper(westpa.core.binning.FuncBinMapper):
         #  This isn't actually used for anything else, and no clustering happens for these, so I can actually
         #  set these arbitrarily.
         original_pcoords = final_coords[:, :self.n_original_pcoord_dims]
+        extended_pcoords = final_coords[:, self.n_original_pcoord_dims:]
 
         basis_we_bin_idx, target_we_bin_idx = self.nbins-2, self.nbins-1
 
@@ -249,23 +252,26 @@ class OptimizedBinMapper(westpa.core.binning.FuncBinMapper):
         # Each segment will be
         #   1. Assigned a WE bin, based on its pcoords and the provided bin mapper
         #   2. Discretized, according to the k-means model associated with that WE bin
-        log.debug(f"About to cluster coords of shape {final_coords.shape}")
-        stratified_cluster_assignments = self.clusterer.predict(final_coords)
+        log.debug(f"About to cluster coords of shape {extended_pcoords.shape}")
 
-        log.info(f"Got microstate assignments {stratified_cluster_assignments}")
+        # TODO: Do I just want final_coords[:, self.n_original_pcoord_dims:]?
+
+        stratified_cluster_assignments = self.clusterer.predict(extended_pcoords)
+
+        log.debug(f"Got microstate assignments {stratified_cluster_assignments}")
 
         # TODO: Map microstates to new WE bins, and populate we_bin_assignments
         # I have a microstate for each segment now -- I need to refer to my mapping of microstates to WE bins, which
         #   just comes from my optimization step
-        log.info(f"Mapping microstates to WE bins using {self.microstate_mapper}")
+        log.debug(f"Mapping microstates to WE bins using {self.microstate_mapper}")
 
         we_bin_assignments = np.array([float(self.microstate_mapper[microstate])
                                        if microstate < len(self.microstate_mapper) else -1
                                        for microstate in stratified_cluster_assignments
                                       ])
 
-        log.info(f"Basis WE bin is labeled {basis_we_bin_idx}, target WE bin is labeled {target_we_bin_idx}")
-        log.info(f"WE bin assignments before correcting basis/target are {we_bin_assignments}")
+        log.debug(f"Basis WE bin is labeled {basis_we_bin_idx}, target WE bin is labeled {target_we_bin_idx}")
+        log.debug(f"WE bin assignments before correcting basis/target are {we_bin_assignments}")
 
         we_bin_assignments[self.clusterer.model.is_WE_target(final_coords)] = target_we_bin_idx
         we_bin_assignments[self.clusterer.model.is_WE_basis(final_coords)] = basis_we_bin_idx
@@ -273,7 +279,7 @@ class OptimizedBinMapper(westpa.core.binning.FuncBinMapper):
         zipped_assignments = np.array(list(zip(original_pcoords.reshape(-1), we_bin_assignments)))
         zip_sort = np.argsort(original_pcoords.reshape(-1))
 
-        log.info(f"WE bin assignments are {zipped_assignments[zip_sort]}")
+        log.debug(f"WE bin assignments are {zipped_assignments[zip_sort]}")
 
         for i in range(len(output)):
             output[i] = we_bin_assignments[i]
